@@ -13,7 +13,7 @@
   File:	      YPerl.cc
 
   Maintainer: Martin Vidner <mvidner@suse.cz>
-  Author:     Stefan Hundhammer <sh@suse.de>
+  Author:     Stefan Hundhammer <shundhammer@suse.de>
 
   This is the common part, defining data type conversions.
 
@@ -26,6 +26,8 @@
 #include <sstream>
 #include <iomanip>
 #include <limits>
+#include <locale.h>
+#include <langinfo.h>
 
 // Perl stuff
 #define PERL_NO_GET_CONTEXT     /* we want efficiency, man perlguts */
@@ -114,6 +116,7 @@ YPerl::YPerl()
 		0 );	// env
 
     PrependModulePath (internalPerlInterpreter ());
+    fixupLocale();
 }
 
 YPerl::YPerl(pTHX)
@@ -142,6 +145,35 @@ YPerl::yPerl()
     return _yPerl;
 }
 
+
+void YPerl::fixupLocale()
+{
+#if 0
+    y2milestone( "Switching to the global locale" );
+
+    uselocale( LC_GLOBAL_LOCALE ); // bsc#1216689
+    // Unfortunately, while this fixed bsc#1216689 (broken special characters),
+    // it seems to have caused bsc#1220375 (yast2-users crashing with a
+    // Zypp-Main process in a busy loop), so we needed to revert this again.
+#else
+    // Some log output to be able to identify versions with and without the
+    // above fix/workaround.
+    //
+    // TO DO: Remove this whole #if 0 .. #endif block after a real fix.
+    y2milestone( "NOT switching to the global locale - leaving whatever Perl did" );
+#endif
+
+    // Those functions only query the current values,
+    // they don't change anything.
+
+    char * locale  = setlocale( LC_ALL, 0 );
+    char * codeset = nl_langinfo( CODESET );
+
+    y2milestone( "locale:  %s", locale  ? locale  : "<NULL>" );
+    y2milestone( "codeset: %s", codeset ? codeset : "<NULL>" );
+}
+
+
 void
 YPerl::acceptInterpreter (pTHX)
 {
